@@ -56,6 +56,8 @@ class ThreadBuffer(Buffer):
         info['message_count'] = self.message_count
         info['thread_tags'] = self.translated_tags_str()
         info['intersection_tags'] = self.translated_tags_str(intersection=True)
+        info['mimetype'] = (
+            self.get_selected_message().mime_part.get_content_type())
         return info
 
     def get_selected_thread(self):
