@@ -28,7 +28,9 @@ from .widgets.globals import ChoiceWidget
 async def periodic(callable_, period, *args, **kwargs):
     while True:
         try:
-            callable_(*args, **kwargs)
+            t = callable_(*args, **kwargs)
+            if asyncio.iscoroutine(t):
+                await t
         except Exception as e:
             logging.error('error in loop hook %s', str(e))
         await asyncio.sleep(period)
@@ -134,6 +136,9 @@ class UI:
         logging.info('setup gui in %d colours', colourmode)
         self.mainloop.screen.set_terminal_properties(colors=colourmode)
 
+        # clear the screen before the initial frame
+        self.mainloop.screen.clear()
+
         logging.debug('fire first command')
         loop.create_task(self.apply_commandline(initialcmdline))
 
